@@ -98,26 +98,40 @@ expect_error(tiledb:::libtiledb_array_schema_set_capacity(sch@ptr, -10))
 dir.create(uri <- tempfile())
 key <- "0123456789abcdeF0123456789abcdeF"
 
+oldconfig <- config <- tiledb_config()
+config <- tiledb_config()
+config["sm.encryption_type"] <- "AES_256_GCM";
+config["sm.encryption_key"] <- key
+ctx <- tiledb_ctx(config)
+
+## quick and direct test write with encryption
+expect_silent( fromDataFrame(palmerpenguins::penguins, uri) )
+
+## check access, here just schema return and number of rows when read
+expect_true(is(schema(uri), "tiledb_array_schema"))
+expect_equal(nrow(tiledb_array(uri, return_as="data.frame")[]), 344)
+
+unlink(uri, recursive=TRUE)
+
+## previous test
 dom <- tiledb_domain(dims = c(tiledb_dim("rows", c(1L, 4L), 4L, "INT32"),
                               tiledb_dim("cols", c(1L, 4L), 4L, "INT32")))
 schema <- tiledb_array_schema(dom, attrs = c(tiledb_attr("a", type = "INT32")))
-
-##tiledb_array_create_with_key(uri, schema, key)
-## for now calling into function
-tiledb:::libtiledb_array_create_with_key(uri, schema@ptr, key)
-
-##expect_true(is(schema(A), "tiledb_dense"))
-## can't yet read / write as scheme getter not generalized for encryption
+tiledb_array_create(uri, schema, key)
+expect_true(is(schema(uri), "tiledb_array_schema"))
 
 unlink(uri, recursive=TRUE)
+
+ctx <- tiledb_ctx(oldconfig)  # reset to no encryption via previous config
+
+
 #})
 
 #test_that("tiledb_array_schema dups setter/getter",  {
 dom <- tiledb_domain(dims = c(tiledb_dim("rows", c(1L, 4L), 4L, "INT32"),
                               tiledb_dim("cols", c(1L, 4L), 4L, "INT32")))
-sch <- tiledb_array_schema(dom,
-                           attrs = c(tiledb_attr("a", type = "INT32")),
-                           sparse = TRUE)
+attr <- tiledb_attr("a", type = "INT32")
+sch <- tiledb_array_schema(dom, attrs = attr, sparse = TRUE)
 
 ## false by default
 expect_false(allows_dups(sch))
@@ -126,3 +140,13 @@ expect_false(allows_dups(sch))
 allows_dups(sch) <- TRUE
 expect_true(allows_dups(sch))
 #})
+
+
+## current domain
+if (tiledb_version(TRUE) < "2.25.0") exit_file("Needs TileDB 2.25.* or later")
+expect_error(tiledb_array_schema_get_current_domain(dom))           # wrong object
+expect_silent(cd <- tiledb_array_schema_get_current_domain(sch))
+expect_silent(tiledb_array_schema_set_current_domain(sch, cd))
+
+dsch <- tiledb_array_schema(dom, attrs = attr, sparse = FALSE)
+expect_error(tiledb_array_schema_set_current_domain(dsch, cd)) 		# not for dense
